結果
| 問題 | No.224 文字列変更(easy) |
| コンテスト | |
| ユーザー |
Furu M
|
| 提出日時 | 2021-03-19 00:21:56 |
| 言語 | Python3 (3.15.0 + numpy 2.5.4 + scipy 1.18.1 + ACL) |
| 結果 |
AC
不安定
|
| 実行時間 | 21 ms / 5,000 ms |
| + 660µs | |
| コード長 | 99 bytes |
| 記録 | |
| コンパイル時間 | 55 ms |
| コンパイル使用メモリ | 15,232 KB |
| 実行使用メモリ | 10,880 KB |
| 最終ジャッジ日時 | 2026-09-25 06:06:01 |
| 合計ジャッジ時間 | 1,900 ms |
|
ジャッジサーバーID (参考情報) |
judge2_0 / judge1_0 |
(要ログイン)
| ファイルパターン | 結果 |
|---|---|
| other | AC * 22 |
ソースコード
N=int(input()) A=list(input()) B=list(input()) O=0 for i in range(N): if A[i]!=B[i]:O+=1 print(O)
Furu M